@@ -46,6 +46,11 @@
 static uid_t _original_UID ;
 static const char * _run_time_path ;
 
+/*
+ * set the function to be called when an attempt to evelate or downgrade privileges fail.
+ */
+static void ( *zuluCryptSecurityPrivilegeElevationError )( const char * ) = NULL ;
+
 const char * zuluCryptRunTimePath()
 {
 	return _run_time_path ;
@@ -84,12 +89,12 @@ int zuluCryptSecurityConvertUID( uid_t uid,const char * u_id )
 
 		if( uid == 0 ){
 
-			return StringConvertToInt( u_id ) ;
+			return (int)StringConvertToInt( u_id ) ;
 		}else{
 			return -1 ;
 		}
 	}else{
-		return uid ;
+		return (int)uid ;
 	}
 }
 
@@ -99,8 +104,6 @@ void zuluCryptSetUserUIDForPrivilegeManagement( uid_t uid )
 	global_variable_user_uid = uid ;
 }
 
-void ( *zuluCryptSecurityPrivilegeElevationError )( const char * ) = NULL ;
-
 void zuluCryptSecuritySetPrivilegeElevationErrorFunction( void ( *f ) ( const char * ) )
 {
 	zuluCryptSecurityPrivilegeElevationError = f ;
@@ -160,8 +163,8 @@ void zuluCryptSecuritySanitizeTheEnvironment( uid_t uid,stringList_t * stx )
 
 		if( index >= 0 ){
 
-			unsetenv( StringSubChar( st,index,'\0' ) ) ;
-			StringSubChar( st,index,'=' ) ;
+			unsetenv( StringSubChar( st,(size_t)index,'\0' ) ) ;
+			StringSubChar( st,(size_t)index,'=' ) ;
 		}
 	}
 
@@ -178,7 +181,7 @@ void zuluCryptSecuritySanitizeTheEnvironment( uid_t uid,stringList_t * stx )
 
 int zuluCryptSecurityUserOwnTheFile( const char * device,uid_t uid )
 {
-	if( device && uid ){ ; }
+	if( device && uid ){}
 	return 0 ;
 }
 
