@@ -55,6 +55,9 @@ createvolume::createvolume( QWidget * parent ) : QDialog( parent ),m_ui( new Ui:
 	m_isWindowClosable = true ;
 	m_warned = false ;
 
+	m_ui->lineEditIterationNumber->setVisible( false ) ;
+	m_ui->labelIterationNumber->setVisible( false ) ;
+
 	connect( m_ui->pbOpenKeyFile,SIGNAL( clicked() ),this,SLOT( pbOpenKeyFile() ) ) ;
 	connect( m_ui->pbCreate,SIGNAL( clicked() ),this,SLOT( pbCreateClicked() ) ) ;
 	connect( m_ui->pbCancel,SIGNAL( clicked() ),this,SLOT( pbCancelClicked() ) ) ;
@@ -110,9 +113,11 @@ createvolume::createvolume( QWidget * parent ) : QDialog( parent ),m_ui( new Ui:
 	m_ui->comboBoxVolumeType->addItem( tr( "Normal+Hidden TrueCrypt" ) ) ;
 	m_ui->comboBoxVolumeType->addItem( tr( "Normal VeraCrypt" ) ) ;
 	m_ui->comboBoxVolumeType->addItem( tr( "Normal+Hidden VeraCrypt" ) ) ;
-
+#ifdef CRYPT_LUKS2
+	m_ui->comboBoxVolumeType->setCurrentIndex( int( createvolume::luks2 ) ) ;
+#else
 	m_ui->comboBoxVolumeType->setCurrentIndex( int( createvolume::luks ) ) ;
-
+#endif
 	m_ui->comboBoxHiddenSize->setCurrentIndex( 2 ) ;
 
 	this->setOptions( 1 ) ;
@@ -396,6 +401,12 @@ void createvolume::setOptions( int e )
 		#endif
 	} ;
 
+	auto luksSelected = _luks() ;
+
+	m_ui->lineEditIterationNumber->setVisible( luksSelected ) ;
+	m_ui->labelIterationNumber->setVisible( luksSelected ) ;
+	m_ui->lineEditIterationNumber->clear() ;
+
 	if( _plain_dmcrypt() ){
 
 		/*
@@ -411,7 +422,7 @@ void createvolume::setOptions( int e )
 			options->addItems( s ) ;
 		}
 
-	}else if( _luks() ){
+	}else if( luksSelected ){
 
 		/*
 		 * cryto options for LUKS volumes.
@@ -755,6 +766,9 @@ void createvolume::HideUI()
 
 void createvolume::enableAll()
 {
+	m_ui->lineEditIterationNumber->setEnabled( true ) ;
+	m_ui->labelIterationNumber->setEnabled( true ) ;
+
 	auto enable = m_ui->comboBoxVolumeType->currentText().contains( "VeraCrypt" ) ;
 
 	m_ui->label_2->setEnabled( enable ) ;
@@ -820,6 +834,8 @@ void createvolume::enableAll()
 
 void createvolume::disableAll()
 {
+	m_ui->lineEditIterationNumber->setEnabled( false ) ;
+	m_ui->labelIterationNumber->setEnabled( false ) ;
 	m_ui->label_2->setEnabled( false ) ;
 	m_ui->lineEditPIM->setEnabled( false ) ;
 	m_ui->labelPassPhrase->setEnabled( false ) ;
@@ -861,7 +877,7 @@ void createvolume::pbCreateClicked()
 
 	this->disableAll() ;
 
-	utility::raii raii( [ this ](){ this->enableAll() ; } ) ;
+	utility2::raii raii( [ this ](){ this->enableAll() ; } ) ;
 
 	if( utility::requireSystemPermissions( volumePath ) ){
 
@@ -1035,6 +1051,13 @@ void createvolume::pbCreateClicked()
 
 			g += "." + e ;
 		}
+	}else{
+		auto m = m_ui->lineEditIterationNumber->text() ;
+
+		if( !m.isEmpty() ){
+
+			g += "." + m ;
+		}
 	}
 
 	volumePath.replace( "\"","\"\"\"" ) ;
